diff --git a/books/bookvol10.4.pamphlet b/books/bookvol10.4.pamphlet
index c72984e..8f6b4dd 100644
--- a/books/bookvol10.4.pamphlet
+++ b/books/bookvol10.4.pamphlet
@@ -49509,6 +49509,17 @@ Using the half extended Euclidean algorithm we compute 1/a mod b.
 The Chinese Remainder Algorithm
 ====================================================================
 
+The Chinese Remainder Theorem says that given n moduli m_i for 
+(1 <= i <= n) of pairwise coprime integers and a set of congruential 
+equations x \equiv c_i (mod m_i) (1 <= i <= n) for an arbitrary 
+integer x, there is a unique solution c for x modulo the product 
+M = \prod_{i=1}^n {m_i}, say x \equiv c (mod M).
+
+If the upper bound B of the absolute value of x is known, that is, if
+|x| <= B then the number of moduli can be chosen such that B < M/2. If
+c is the absolutely least residue modulo M then c and x coincide so x
+is uniquely determined.
+
 Let m1,m2,...,mr be positive integers that are pairwise relatively prime. 
 Let x1,x2,..,xr be integers with 0 <= xi < mi. Then, there is exactly one 
 x in the interval 0 <= x < m1 ... m2 ... mr
diff --git a/books/bookvolbib.pamphlet b/books/bookvolbib.pamphlet
index 015ba36..2e39b27 100644
--- a/books/bookvolbib.pamphlet
+++ b/books/bookvolbib.pamphlet
@@ -1,14 +1,305 @@
-\documentclass{article}
+\documentclass[dvipdfm]{book}
+\usepackage{hyperref}
+\usepackage{axiom}
+\usepackage{makeidx}
+\makeindex
+\usepackage{graphicx}
+% struggle with latex figure-floating behavior
+\renewcommand\floatpagefraction{.9}
+\renewcommand\topfraction{.9}
+\renewcommand\bottomfraction{.9}
+\renewcommand\textfraction{.1}
+\setcounter{totalnumber}{50}
+\setcounter{topnumber}{50}
+\setcounter{bottomnumber}{50}
+
+
+%% spadgraph are the actual text that you type at the axiom prompt for draw
+\providecommand{\spadgraph}[1]%
+{\begin{flushleft}{\tt #1}\end{flushleft}\vskip .1cm }
+
+% spadfunFrom records the function name and domain in the index
+\providecommand{\spadfunFrom}[2]%
+{{\bf #1}\index{#1 @\begingroup \string\bf{} #1 \endgroup}\index{#2}}
+
+%% spadsig gives the standard -> notation for signatures
+\providecommand{\spadsig}[2]{{\sf #1 $\rightarrow$ #2}}
+
+% special meanings for math characters
+\providecommand{\N}{\mbox{\bbold N}}
+\providecommand{\Natural}{\mbox{\bbold N}}
+\providecommand{\Z}{\mbox{\bbold Z}}
+\providecommand{\Integer}{\mbox{\bbold Z}}
+\providecommand{\Rational}{\mbox{\bbold Q}}
+\providecommand{\Q}{\mbox{\bbold Q}}
+\providecommand{\Complex}{\mbox{\bbold C}}
+\providecommand{\C}{{\mathcal C}}
+\providecommand{\Real}{\mbox{\bbold R}}
+\providecommand{\F}{{\mathcal F}}
+\providecommand{\R}{{\mathcal R}}
+
+% draw a box around a text block
+\providecommand\boxed[2]{%
+\begin{center}
+\begin{tabular}{|c|}
+\hline
+\begin{minipage}{#1}
+\normalsize
+{#2}
+\end{minipage}\\
+\hline
+\end{tabular}
+\end{center}}
+
+\providecommand{\optArg}[1]{{{\tt [}{#1}{\tt ]}}}
+\providecommand{\argDef}[1]{{\tt ({#1})}}
+\providecommand{\funSyntax}[2]{{\bf #1}{\tt ({\small\it{#2}})}}
+\providecommand{\funArgs}[1]{{\tt ({\small\it {#1}})}\newline}
+\providecommand{\condata}[4]{{\bf #1} {\bf #2} {\bf #3} {\bf #4}}
+
+\def\glossaryTerm#1{{\bf #1}\index{#1}}
+\def\glossaryTermNoIndex#1{{\bf #1}}
+\def\glossarySyntaxTerm#1{{\tt #1}\index{#1}}
+\long\def\ourGloss#1#2{\par\pagebreak[3]{#1}\newline{#2}}
+\def\csch{\mathop{\rm csch}\nolimits}
+
+\def\erf{\mathop{\rm erf}\nolimits}
+
+\def\zag#1#2{
+  {{\hfill \left. {#1} \right|}
+   \over
+   {\left| {#2} \right. \hfill}
+  }
+}
+
+
+% these bitmaps are used by HyperDoc
+\newdimen\commentWidth 
+\commentWidth=11pc
+\newdimen\colGutterWidth 
+\colGutterWidth=1pc
+\newdimen\baseLeftSkip
+\baseLeftSkip=\commentWidth \advance\baseLeftSkip by \colGutterWidth
+
+\providecommand\ExitBitmap%
+{{\setlength{\unitlength}{0.01in}%
+\begin{picture}(50,16)(0,0)\special{psfile=ps/exit.ps}\end{picture}}}
+
+\providecommand\ReturnBitmap%
+{{\setlength{\unitlength}{0.01in}%
+\begin{picture}(50,16)(0,0)\special{psfile=ps/home.ps}\end{picture}}}
+
+\providecommand\HelpBitmap%
+{{\setlength{\unitlength}{0.01in}%
+\begin{picture}(50,16)(0,0)\special{psfile=ps/help.ps}\end{picture}}}
+
+\providecommand\UpBitmap%
+{{\setlength{\unitlength}{0.01in}%
+\begin{picture}(50,16)(0,0)\special{psfile=ps/up.ps}\end{picture}}}
+
+\providecommand{\tpd}[5]%
+{{\setlength{\unitlength}{0.01in}%
+\begin{picture}(#1,#2)(#3,#4)\special{psfile=#5}\end{picture}}}
+
 \begin{document}
-\title{Axiom Literature Citations}
-\author{Nelson H. F. Beebe and Timothy Daly}
-\maketitle
-\begin{abstract}
+\begin{titlepage}
+\center{\includegraphics{ps/axiomfront.ps}}
+\vskip 0.1in
+\includegraphics{ps/bluebayou.ps}\\
+\vskip 0.1in
+{\Huge{The 30 Year Horizon}}
+\vskip 0.1in
+$$
+\begin{array}{lll}
+Manuel\ Bronstein      & William\ Burge   & Timothy\ Daly \\
+James\ Davenport       & Michael\ Dewar   & Martin\ Dunstan \\
+Albrecht\ Fortenbacher & Patrizia\ Gianni & Johannes\ Grabmeier \\
+Jocelyn\ Guidry        & Richard\ Jenks   & Larry\ Lambe \\
+Michael\ Monagan       & Scott\ Morrison  & William\ Sit \\
+Jonathan\ Steinbach    & Robert\ Sutor    & Barry\ Trager \\
+Stephen\ Watt          & Jim\ Wen         & Clifton\ Williamson
+\end{array}
+$$
+\center{\large{Volume Bibliography: Axiom Literature Citations}}
+\end{titlepage}
+\pagenumbering{roman}
+\begin{verbatim}
+Portions Copyright (c) 2005 Timothy Daly
+
+The Blue Bayou image Copyright (c) 2004 Jocelyn Guidry
+
+Portions Copyright (c) 2004 Martin Dunstan
+
+Portions Copyright (c) 1991-2002, 
+The Numerical ALgorithms Group Ltd.
+All rights reserved.
+
+This book and the Axiom software is licensed as follows:
+
+Redistribution and use in source and binary forms, with or 
+without modification, are permitted provided that the following 
+conditions are
+met:
+
+    - Redistributions of source code must retain the above 
+      copyright notice, this list of conditions and the 
+      following disclaimer.
+
+    - Redistributions in binary form must reproduce the above
+      copyright notice, this list of conditions and the 
+      following disclaimer in the documentation and/or other 
+      materials provided with the distribution.
+
+    - Neither the name of The Numerical ALgorithms Group Ltd. 
+      nor the names of its contributors may be used to endorse 
+      or promote products derived from this software without 
+      specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND 
+CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
+INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
+MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
+CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
+SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
+BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
+SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
+INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
+WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
+SUCH DAMAGE.
+\end{verbatim}
+
+Inclusion of names in the list of credits is based on historical
+information and is as accurate as possible. Inclusion of names
+does not in any way imply an endorsement but represents historical
+influence on Axiom development.
+\vfill
+\eject
+\begin{tabular}{lll}
+Cyril Alberga         & Roy Adler             & Richard Anderson\\
+George Andrews        & Henry Baker           & Stephen Balzac\\
+Yurij Baransky        & David R. Barton       & Gerald Baumgartner\\
+Gilbert Baumslag      & Fred Blair            & Vladimir Bondarenko\\
+Mark Botch            & Alexandre Bouyer      & Peter A. Broadbery\\
+Martin Brock          & Manuel Bronstein      & Florian Bundschuh\\
+William Burge         & Quentin Carpent       & Bob Caviness\\
+Bruce Char            & Cheekai Chin          & David V. Chudnovsky\\
+Gregory V. Chudnovsky & Josh Cohen            & Christophe Conil\\
+Don Coppersmith       & George Corliss        & Robert Corless\\
+Gary Cornell          & Meino Cramer          & Claire Di Crescenzo\\
+Timothy Daly Sr.      & Timothy Daly Jr.      & James H. Davenport\\
+Jean Della Dora       & Gabriel Dos Reis      & Michael Dewar\\
+Claire DiCrescendo    & Sam Dooley            & Lionel Ducos\\
+Martin Dunstan        & Brian Dupee           & Dominique Duval\\
+Robert Edwards        & Heow Eide-Goodman     & Lars Erickson\\
+Richard Fateman       & Bertfried Fauser      & Stuart Feldman\\
+Brian Ford            & Albrecht Fortenbacher & George Frances\\
+Constantine Frangos   & Timothy Freeman       & Korrinn Fu\\
+Marc Gaetano          & Rudiger Gebauer       & Kathy Gerber\\
+Patricia Gianni       & Holger Gollan         & Teresa Gomez-Diaz\\
+Laureano Gonzalez-Vega& Stephen Gortler       & Johannes Grabmeier\\
+Matt Grayson          & James Griesmer        & Vladimir Grinberg\\
+Oswald Gschnitzer     & Jocelyn Guidry        & Steve Hague\\
+Vilya Harvey          & Satoshi Hamaguchi     & Martin Hassner\\
+Ralf Hemmecke         & Henderson             & Antoine Hersen\\
+Pietro Iglio          & Richard Jenks         & Kai Kaminski\\
+Grant Keady           & Tony Kennedy          & Paul Kosinski\\
+Klaus Kusche          & Bernhard Kutzler      & Larry Lambe\\
+Frederic Lehobey      & Michel Levaud         & Howard Levy\\
+Rudiger Loos          & Michael Lucks         & Richard Luczak\\
+Camm Maguire          & Bob McElrath          & Michael McGettrick\\
+Ian Meikle            & David Mentre          & Victor S. Miller\\
+Gerard Milmeister     & Mohammed Mobarak      & H. Michael Moeller\\
+Michael Monagan       & Marc Moreno-Maza      & Scott Morrison\\
+Mark Murray           & William Naylor        & C. Andrew Neff\\
+John Nelder           & Godfrey Nolan         & Arthur Norman\\
+Jinzhong Niu          & Michael O'Connor      & Kostas Oikonomou\\
+Julian A. Padget      & Bill Page             & Jaap Weel\\
+Susan Pelzel          & Michel Petitot        & Didier Pinchon\\
+Claude Quitte         & Norman Ramsey         & Michael Richardson\\
+Renaud Rioboo         & Jean Rivlin           & Nicolas Robidoux\\
+Simon Robinson        & Michael Rothstein     & Martin Rubey\\
+Philip Santas         & Alfred Scheerhorn     & William Schelter\\
+Gerhard Schneider     & Martin Schoenert      & Marshall Schor\\
+Fritz Schwarz         & Nick Simicich         & William Sit\\
+Elena Smirnova        & Jonathan Steinbach    & Christine Sundaresan\\
+Robert Sutor          & Moss E. Sweedler      & Eugene Surowitz\\
+James Thatcher        & Baldir Thomas         & Mike Thomas\\
+Dylan Thurston        & Barry Trager          & Themos T. Tsikas\\
+Gregory Vanuxem       & Bernhard Wall         & Stephen Watt\\
+Juergen Weiss         & M. Weller             & Mark Wegman\\
+James Wen             & Thorsten Werther      & Michael Wester\\
+John M. Wiley         & Berhard Will          & Clifton J. Williamson\\
+Stephen Wilson        & Shmuel Winograd       & Robert Wisbauer\\
+Sandra Wityak         & Waldemar Wiwianka     & Knut Wolf\\
+Clifford Yapp         & David Yun             & Richard Zippel\\
+Evelyn Zoernack       & Bruno Zuercher        & Dan Zwillinger 
+\end{tabular}
+\eject
+\tableofcontents
+\vfill
+\eject
+\setlength{\parindent}{0em}
+\setlength{\parskip}{1ex}
+{\Large{\bf New Foreword}}
+\vskip .25in
+
+On October 1, 2001 Axiom was withdrawn from the market and ended
+life as a commercial product.
+On September 3, 2002 Axiom was released under the Modified BSD
+license, including this document.
+On August 27, 2003 Axiom was released as free and open source
+software available for download from the Free Software Foundation's
+website, Savannah.
+
+Work on Axiom has had the generous support of the Center for 
+Algorithms and Interactive Scientific Computation (CAISS) at
+City College of New York. Special thanks go to Dr. Gilbert 
+Baumslag for his support of the long term goal.
+
+The online version of this documentation is roughly 1000 pages.
+In order to make printed versions we've broken it up into three
+volumes. The first volume is tutorial in nature. The second volume
+is for programmers. The third volume is reference material. We've
+also added a fourth volume for developers. All of these changes
+represent an experiment in print-on-demand delivery of documentation.
+Time will tell whether the experiment succeeded.
+
+Axiom has been in existence for over thirty years. It is estimated to
+contain about three hundred man-years of research and has, as of
+September 3, 2003, 143 people listed in the credits. All of these
+people have contributed directly or indirectly to making Axiom
+available.  Axiom is being passed to the next generation. I'm looking
+forward to future milestones.
+
+With that in mind I've introduced the theme of the ``30 year horizon''.
+We must invent the tools that support the Computational Mathematician
+working 30 years from now. How will research be done when every bit of
+mathematical knowledge is online and instantly available? What happens
+when we scale Axiom by a factor of 100, giving us 1.1 million domains?
+How can we integrate theory with code? How will we integrate theorems
+and proofs of the mathematics with space-time complexity proofs and
+running code? What visualization tools are needed? How do we support
+the conceptual structures and semantics of mathematics in effective
+ways? How do we support results from the sciences? How do we teach
+the next generation to be effective Computational Mathematicians?
+
+The ``30 year horizon'' is much nearer than it appears.
+
+\vskip .25in
+%\noindent
+Tim Daly\\
+CAISS, City College of New York\\
+November 10, 2003 ((iHy))
+\vfill
+\eject
 A bibliography of Axiom references which are used throughout
 Axiom. The first section contains literature that mentions Axiom,
 initially derived with permission from Nelson Beebe's collection.
 The second section contains references from Axiom to the literature.
-\end{abstract}
+
 \section{Axiom Citations in the Literature}
 \begin{thebibliography}{999}
 \bibitem[ACM89]{ACM89} 
@@ -717,6 +1008,10 @@ Lecture Notes in Computer Science, vol. 948, 1995, pp. 262--278.
 Hach\'e, G. ``Construction effective des codes g\'eom\'etriques''
 Th\'ese de doctorat de l'Universit\'e Pierre et Marie Curie (Paris 6), 
 Septembre 1996.
+\bibitem[Ham04]{Ham04}
+Hamdy, S. ``LiDIA A library for computational number theory''
+Reference manual Edition 2.1.1 May 2004
+\verb|www.cdc.informatik.tu-darmstadt.de/TI/LiDIA|
 \bibitem[Her1872]{Her1872}
 E. Hermite. Sur l'int\'{e}gration des fractions
 rationelles. {\sl Nouvelles Annales de Math\'{e}matiques}
diff --git a/changelog b/changelog
index 464bcad..776f2e5 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20100920 tpd src/axiom-website/patches.html 20100920.02.tpd.patch
+20100920 tpd books/bookvolbib add Hamdy [Ham04]
+20100920 tpd books/bookvol10.4 update Chinese Remainder documentation
 20100920 tpd src/axiom-website/patches.html 20100920.01.tpd.patch
 20100920 tpd src/input/test.input clean up broken tests
 20100920 tpd src/input/setcmd.input clean up broken tests
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 6f7a455..8b5af8c 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -3133,5 +3133,7 @@ books/bookvol9 treeshake compiler<br/>
 books/bookvol9 treeshake compiler<br/>
 <a href="patches/20100920.01.tpd.patch">20100920.01.tpd.patch</a>
 src/input/*.input clean up broken tests<br/>
+<a href="patches/20100920.02.tpd.patch">20100920.02.tpd.patch</a>
+books/bookvol10.4 update Chinese Remainder documentation<br/>
  </body>
 </html>
